==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobPriority.h <==
// public final class javax.print.attribute.standard.JobPriority

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax
// @dep_class ab232950fcd672d5 javax_print_attribute_standard_JobPriority

// header file dependencies
// @dep_header javax_print_attribute_IntegerSyntax

#include "javax/print/attribute/IntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobPriority_H_
#define _JC_javax_print_attribute_standard_JobPriority_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobPriority$sub_refs	_jc_javax_print_attribute_standard_JobPriority$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$sub_nonrefs	_jc_javax_print_attribute_standard_JobPriority$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$refs	_jc_javax_print_attribute_standard_JobPriority$refs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$nonrefs	_jc_javax_print_attribute_standard_JobPriority$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$object	_jc_javax_print_attribute_standard_JobPriority$object;

typedef struct _jc_javax_print_attribute_standard_JobPriority$fields_struct	_jc_javax_print_attribute_standard_JobPriority$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobPriority$vmethods	_jc_javax_print_attribute_standard_JobPriority$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobPriority$vtable	_jc_javax_print_attribute_standard_JobPriority$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobPriority$vtype	_jc_javax_print_attribute_standard_JobPriority$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobPriority$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobPriority;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobPriority$fields_struct _jc_javax_print_attribute_standard_JobPriority$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobPriority$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *, jint);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_JobPriority$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobPriority$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobPriority$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobPriority$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_JobPriority$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobPriority$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobPriority$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobPriority$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobPriority$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
	_jc_javax_print_attribute_standard_JobPriority$vmethods	javax_print_attribute_standard_JobPriority;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobPriority$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobPriority$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobPriority$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobPriority$refs {
    _jc_javax_print_attribute_standard_JobPriority$sub_refs	javax_print_attribute_standard_JobPriority;
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobPriority$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobPriority$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
    _jc_javax_print_attribute_standard_JobPriority$sub_nonrefs	javax_print_attribute_standard_JobPriority;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobPriority$object {
	_jc_javax_print_attribute_standard_JobPriority$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobPriority$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobPriority$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobPriority$vtype _jc_javax_print_attribute_standard_JobPriority$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobPriority, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobPriority$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobPriority_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobPriority.h <==
// public final class javax.print.attribute.standard.JobPriority

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax
// @dep_class ab232950fcd672d5 javax_print_attribute_standard_JobPriority

// header file dependencies
// @dep_header javax_print_attribute_IntegerSyntax

#include "javax/print/attribute/IntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobPriority_H_
#define _JC_javax_print_attribute_standard_JobPriority_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobPriority$sub_refs	_jc_javax_print_attribute_standard_JobPriority$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$sub_nonrefs	_jc_javax_print_attribute_standard_JobPriority$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$refs	_jc_javax_print_attribute_standard_JobPriority$refs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$nonrefs	_jc_javax_print_attribute_standard_JobPriority$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobPriority$object	_jc_javax_print_attribute_standard_JobPriority$object;

typedef struct _jc_javax_print_attribute_standard_JobPriority$fields_struct	_jc_javax_print_attribute_standard_JobPriority$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobPriority$vmethods	_jc_javax_print_attribute_standard_JobPriority$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobPriority$vtable	_jc_javax_print_attribute_standard_JobPriority$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobPriority$vtype	_jc_javax_print_attribute_standard_JobPriority$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobPriority$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobPriority;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobPriority$fields_struct _jc_javax_print_attribute_standard_JobPriority$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobPriority$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_JobPriority$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobPriority$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobPriority$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobPriority$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_JobPriority$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobPriority$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobPriority$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobPriority$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobPriority$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobPriority$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
	_jc_javax_print_attribute_standard_JobPriority$vmethods	javax_print_attribute_standard_JobPriority;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobPriority$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobPriority$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobPriority$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobPriority$refs {
    _jc_javax_print_attribute_standard_JobPriority$sub_refs	javax_print_attribute_standard_JobPriority;
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobPriority$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobPriority$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
    _jc_javax_print_attribute_standard_JobPriority$sub_nonrefs	javax_print_attribute_standard_JobPriority;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobPriority$object {
	_jc_javax_print_attribute_standard_JobPriority$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobPriority$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobPriority$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobPriority$vtype _jc_javax_print_attribute_standard_JobPriority$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobPriority, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobPriority$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobPriority_H_ */
